shithub: pokecrystal

Download patch

ref: 0cf0a5b9b446c7d743355852667a987011839605
parent: 32e7e368f4b3ae61bf4a219e89fc04ac8263f431
parent: 60c71add580aa3aa5b096beeadd9bb83145768f6
author: Rangi <35663410+Rangi42@users.noreply.github.com>
date: Thu Jun 11 06:17:12 EDT 2020

Merge pull request #729 from Rangi42/master

Treat std scripts like specials and predefs

--- a/constants.asm
+++ b/constants.asm
@@ -46,7 +46,6 @@
 INCLUDE "constants/sprite_anim_constants.asm"
 INCLUDE "constants/sprite_constants.asm"
 INCLUDE "constants/sprite_data_constants.asm"
-INCLUDE "constants/std_constants.asm"
 INCLUDE "constants/tileset_constants.asm"
 INCLUDE "constants/trainer_constants.asm"
 INCLUDE "constants/trainer_data_constants.asm"
--- a/constants/std_constants.asm
+++ /dev/null
@@ -1,55 +1,0 @@
-; StdScripts indexes (see engine/events/std_scripts.asm)
-; also used in TileCollisionStdScripts (see data/events/collision_stdscripts.asm)
-	enum_start
-	enum pokecenternurse
-	enum difficultbookshelf
-	enum picturebookshelf
-	enum magazinebookshelf
-	enum teamrocketoath
-	enum incenseburner
-	enum merchandiseshelf
-	enum townmap
-	enum window
-	enum tv
-	enum homepage
-	enum radio1
-	enum radio2
-	enum trashcan
-	enum strengthboulder
-	enum smashrock
-	enum pokecentersign
-	enum martsign
-	enum goldenrodrockets
-	enum radiotowerrockets
-	enum elevatorbutton
-	enum daytotext
-	enum bugcontestresultswarp
-	enum bugcontestresults
-	enum initializeevents
-	enum asknumber1m
-	enum asknumber2m
-	enum registerednumberm
-	enum numberacceptedm
-	enum numberdeclinedm
-	enum phonefullm
-	enum rematchm
-	enum giftm
-	enum packfullm
-	enum rematchgiftm
-	enum asknumber1f
-	enum asknumber2f
-	enum registerednumberf
-	enum numberacceptedf
-	enum numberdeclinedf
-	enum phonefullf
-	enum rematchf
-	enum giftf
-	enum packfullf
-	enum rematchgiftf
-	enum gymstatue1
-	enum gymstatue2
-	enum receiveitem
-	enum receivetogepiegg
-	enum pcscript
-	enum gamecornercoinvendor
-	enum happinesschecknpc
--- a/engine/battle/used_move_text.asm
+++ b/engine/battle/used_move_text.asm
@@ -5,9 +5,9 @@
 	jp WaitBGMap
 
 UsedMoveText:
-; this is a stream of text and asm from 105db9 to 105ef6
 	text_far _ActorNameText
 	text_asm
+
 	ldh a, [hBattleTurn]
 	and a
 	jr nz, .start
--- a/engine/events/bug_contest/contest.asm
+++ b/engine/events/bug_contest/contest.asm
@@ -30,7 +30,7 @@
 
 BugCatchingContestReturnToGateScript:
 	closetext
-	jumpstd bugcontestresultswarp
+	jumpstd BugContestResultsWarpScript
 
 BugCatchingContestTimeUpText:
 	text_far _BugCatchingContestTimeUpText
--- a/engine/events/std_scripts.asm
+++ b/engine/events/std_scripts.asm
@@ -1,57 +1,61 @@
+add_stdscript: MACRO
+\1StdScript::
+	dba \1
+ENDM
+
 StdScripts::
-; entries correspond to constants/std_constants.asm
-	dba PokecenterNurseScript
-	dba DifficultBookshelfScript
-	dba PictureBookshelfScript
-	dba MagazineBookshelfScript
-	dba TeamRocketOathScript
-	dba IncenseBurnerScript
-	dba MerchandiseShelfScript
-	dba TownMapScript
-	dba WindowScript
-	dba TVScript
-	dba HomepageScript
-	dba Radio1Script
-	dba Radio2Script
-	dba TrashCanScript
-	dba StrengthBoulderScript
-	dba SmashRockScript
-	dba PokecenterSignScript
-	dba MartSignScript
-	dba GoldenrodRocketsScript
-	dba RadioTowerRocketsScript
-	dba ElevatorButtonScript
-	dba DayToTextScript
-	dba BugContestResultsWarpScript
-	dba BugContestResultsScript
-	dba InitializeEventsScript
-	dba AskNumber1MScript
-	dba AskNumber2MScript
-	dba RegisteredNumberMScript
-	dba NumberAcceptedMScript
-	dba NumberDeclinedMScript
-	dba PhoneFullMScript
-	dba RematchMScript
-	dba GiftMScript
-	dba PackFullMScript
-	dba RematchGiftMScript
-	dba AskNumber1FScript
-	dba AskNumber2FScript
-	dba RegisteredNumberFScript
-	dba NumberAcceptedFScript
-	dba NumberDeclinedFScript
-	dba PhoneFullFScript
-	dba RematchFScript
-	dba GiftFScript
-	dba PackFullFScript
-	dba RematchGiftFScript
-	dba GymStatue1Script
-	dba GymStatue2Script
-	dba ReceiveItemScript
-	dba ReceiveTogepiEggScript
-	dba PCScript
-	dba GameCornerCoinVendorScript
-	dba HappinessCheckScript
+	add_stdscript PokecenterNurseScript
+	add_stdscript DifficultBookshelfScript
+	add_stdscript PictureBookshelfScript
+	add_stdscript MagazineBookshelfScript
+	add_stdscript TeamRocketOathScript
+	add_stdscript IncenseBurnerScript
+	add_stdscript MerchandiseShelfScript
+	add_stdscript TownMapScript
+	add_stdscript WindowScript
+	add_stdscript TVScript
+	add_stdscript HomepageScript
+	add_stdscript Radio1Script
+	add_stdscript Radio2Script
+	add_stdscript TrashCanScript
+	add_stdscript StrengthBoulderScript
+	add_stdscript SmashRockScript
+	add_stdscript PokecenterSignScript
+	add_stdscript MartSignScript
+	add_stdscript GoldenrodRocketsScript
+	add_stdscript RadioTowerRocketsScript
+	add_stdscript ElevatorButtonScript
+	add_stdscript DayToTextScript
+	add_stdscript BugContestResultsWarpScript
+	add_stdscript BugContestResultsScript
+	add_stdscript InitializeEventsScript
+	add_stdscript AskNumber1MScript
+	add_stdscript AskNumber2MScript
+	add_stdscript RegisteredNumberMScript
+	add_stdscript NumberAcceptedMScript
+	add_stdscript NumberDeclinedMScript
+	add_stdscript PhoneFullMScript
+	add_stdscript RematchMScript
+	add_stdscript GiftMScript
+	add_stdscript PackFullMScript
+	add_stdscript RematchGiftMScript
+	add_stdscript AskNumber1FScript
+	add_stdscript AskNumber2FScript
+	add_stdscript RegisteredNumberFScript
+	add_stdscript NumberAcceptedFScript
+	add_stdscript NumberDeclinedFScript
+	add_stdscript PhoneFullFScript
+	add_stdscript RematchFScript
+	add_stdscript GiftFScript
+	add_stdscript PackFullFScript
+	add_stdscript RematchGiftFScript
+	add_stdscript GymStatue1Script
+	add_stdscript GymStatue2Script
+	add_stdscript ReceiveItemScript
+	add_stdscript ReceiveTogepiEggScript
+	add_stdscript PCScript
+	add_stdscript GameCornerCoinVendorScript
+	add_stdscript HappinessCheckScript
 
 PokecenterNurseScript:
 ; EVENT_WELCOMED_TO_POKECOM_CENTER is never set
--- a/engine/events/whiteout.asm
+++ b/engine/events/whiteout.asm
@@ -22,7 +22,7 @@
 	endall
 
 .bug_contest
-	jumpstd bugcontestresultswarp
+	jumpstd BugContestResultsWarpScript
 
 .WhitedOutText:
 	text_far _WhitedOutText
--- a/engine/gfx/pic_animation.asm
+++ b/engine/gfx/pic_animation.asm
@@ -48,14 +48,10 @@
 
 pokeanim: MACRO
 rept _NARG
-; Workaround for a bug where macro args can't come after the start of a symbol
-if !DEF(\1_POKEANIM)
-\1_POKEANIM EQUS "PokeAnim_\1_"
-endc
-	db (\1_POKEANIM - PokeAnim_SetupCommands) / 2
+	db (PokeAnim_\1_SetupCommand - PokeAnim_SetupCommands) / 2
 	shift
 endr
-	db (PokeAnim_Finish_ - PokeAnim_SetupCommands) / 2
+	db (PokeAnim_Finish_SetupCommand - PokeAnim_SetupCommands) / 2
 ENDM
 
 PokeAnims:
@@ -132,22 +128,24 @@
 	scf
 	ret
 
-PokeAnim_SetupCommands:
-setup_command: MACRO
-\1_: dw \1
+add_setup_command: MACRO
+\1_SetupCommand:
+	dw \1
 ENDM
-	setup_command PokeAnim_Finish
-	setup_command PokeAnim_BasePic
-	setup_command PokeAnim_SetWait
-	setup_command PokeAnim_Wait
-	setup_command PokeAnim_Setup
-	setup_command PokeAnim_Setup2
-	setup_command PokeAnim_Idle
-	setup_command PokeAnim_Play
-	setup_command PokeAnim_Play2
-	setup_command PokeAnim_Cry
-	setup_command PokeAnim_CryNoWait
-	setup_command PokeAnim_StereoCry
+
+PokeAnim_SetupCommands:
+	add_setup_command PokeAnim_Finish
+	add_setup_command PokeAnim_BasePic
+	add_setup_command PokeAnim_SetWait
+	add_setup_command PokeAnim_Wait
+	add_setup_command PokeAnim_Setup
+	add_setup_command PokeAnim_Setup2
+	add_setup_command PokeAnim_Idle
+	add_setup_command PokeAnim_Play
+	add_setup_command PokeAnim_Play2
+	add_setup_command PokeAnim_Cry
+	add_setup_command PokeAnim_CryNoWait
+	add_setup_command PokeAnim_StereoCry
 
 PokeAnim_SetWait:
 	ld a, 18
--- a/engine/link/mystery_gift.asm
+++ b/engine/link/mystery_gift.asm
@@ -1107,7 +1107,7 @@
 	ld d, $0
 	ld b, CHECK_FLAG
 	ld hl, sMysteryGiftDecorationsReceived
-	predef_id SmallFarFlagAction
+	lda_predef SmallFarFlagAction
 	push hl
 	push bc
 	call Predef
--- a/macros/legacy.asm
+++ b/macros/legacy.asm
@@ -327,3 +327,57 @@
 anim_enemyfeetobj  EQUS "anim_battlergfx_2row"
 anim_playerheadobj EQUS "anim_battlergfx_1row"
 anim_clearsprites  EQUS "anim_keepsprites"
+
+; engine/events/std_scripts.asm
+pokecenternurse       EQUS "PokecenterNurseScript"
+difficultbookshelf    EQUS "DifficultBookshelfScript"
+picturebookshelf      EQUS "PictureBookshelfScript"
+magazinebookshelf     EQUS "MagazineBookshelfScript"
+teamrocketoath        EQUS "TeamRocketOathScript"
+incenseburner         EQUS "IncenseBurnerScript"
+merchandiseshelf      EQUS "MerchandiseShelfScript"
+townmap               EQUS "TownMapScript"
+window                EQUS "WindowScript"
+tv                    EQUS "TVScript"
+homepage              EQUS "HomepageScript"
+radio1                EQUS "Radio1Script"
+radio2                EQUS "Radio2Script"
+trashcan              EQUS "TrashCanScript"
+strengthboulder       EQUS "StrengthBoulderScript"
+smashrock             EQUS "SmashRockScript"
+pokecentersign        EQUS "PokecenterSignScript"
+martsign              EQUS "MartSignScript"
+goldenrodrockets      EQUS "GoldenrodRocketsScript"
+radiotowerrockets     EQUS "RadioTowerRocketsScript"
+elevatorbutton        EQUS "ElevatorButtonScript"
+daytotext             EQUS "DayToTextScript"
+bugcontestresultswarp EQUS "BugContestResultsWarpScript"
+bugcontestresults     EQUS "BugContestResultsScript"
+initializeevents      EQUS "InitializeEventsScript"
+asknumber1m           EQUS "AskNumber1MScript"
+asknumber2m           EQUS "AskNumber2MScript"
+registerednumberm     EQUS "RegisteredNumberMScript"
+numberacceptedm       EQUS "NumberAcceptedMScript"
+numberdeclinedm       EQUS "NumberDeclinedMScript"
+phonefullm            EQUS "PhoneFullMScript"
+rematchm              EQUS "RematchMScript"
+giftm                 EQUS "GiftMScript"
+packfullm             EQUS "PackFullMScript"
+rematchgiftm          EQUS "RematchGiftMScript"
+asknumber1f           EQUS "AskNumber1FScript"
+asknumber2f           EQUS "AskNumber2FScript"
+registerednumberf     EQUS "RegisteredNumberFScript"
+numberacceptedf       EQUS "NumberAcceptedFScript"
+numberdeclinedf       EQUS "NumberDeclinedFScript"
+phonefullf            EQUS "PhoneFullFScript"
+rematchf              EQUS "RematchFScript"
+giftf                 EQUS "GiftFScript"
+packfullf             EQUS "PackFullFScript"
+rematchgiftf          EQUS "RematchGiftFScript"
+gymstatue1            EQUS "GymStatue1Script"
+gymstatue2            EQUS "GymStatue2Script"
+receiveitem           EQUS "ReceiveItemScript"
+receivetogepiegg      EQUS "ReceiveTogepiEggScript"
+pcscript              EQUS "PCScript"
+gamecornercoinvendor  EQUS "GameCornerCoinVendorScript"
+happinesschecknpc     EQUS "HappinessCheckScript"
--- a/macros/predef.asm
+++ b/macros/predef.asm
@@ -1,4 +1,4 @@
-predef_id: MACRO
+lda_predef: MACRO
 ; Some functions load the predef id
 ; without immediately calling Predef.
 	ld a, (\1Predef - PredefPointers) / 3
@@ -5,11 +5,11 @@
 ENDM
 
 predef: MACRO
-	predef_id \1
+	lda_predef \1
 	call Predef
 ENDM
 
 predef_jump: MACRO
-	predef_id \1
+	lda_predef \1
 	jp Predef
 ENDM
--- a/macros/scripts/events.asm
+++ b/macros/scripts/events.asm
@@ -80,13 +80,13 @@
 	enum jumpstd_command ; $0c
 jumpstd: MACRO
 	db jumpstd_command
-	dw \1 ; predefined_script
+	dw (\1StdScript - StdScripts) / 3
 ENDM
 
 	enum callstd_command ; $0d
 callstd: MACRO
 	db callstd_command
-	dw \1 ; predefined_script
+	dw (\1StdScript - StdScripts) / 3
 ENDM
 
 	enum callasm_command ; $0e
--- a/maps/AzaleaGym.asm
+++ b/maps/AzaleaGym.asm
@@ -62,10 +62,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 TrainerTwinsAmyandmay1:
 	trainer TWINS, AMYANDMAY1, EVENT_BEAT_TWINS_AMY_AND_MAY, TwinsAmyandmay1SeenText, TwinsAmyandmay1BeatenText, 0, .AfterScript
@@ -142,10 +142,10 @@
 AzaleaGymStatue:
 	checkflag ENGINE_HIVEBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, BUGSY, BUGSY1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 BugsyText_INeverLose:
 	text "I'm BUGSY!"
--- a/maps/AzaleaPokecenter1F.asm
+++ b/maps/AzaleaPokecenter1F.asm
@@ -14,7 +14,7 @@
 	end
 
 AzaleaPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 AzaleaPokecenter1FGentlemanScript:
 	jumptextfaceplayer AzaleaPokecenter1FGentlemanText
--- a/maps/AzaleaTown.asm
+++ b/maps/AzaleaTown.asm
@@ -200,10 +200,10 @@
 	jumptext AzaleaTownIlexForestSignText
 
 AzaleaTownPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 AzaleaTownMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 WhiteApricornTree:
 	fruittree FRUITTREE_AZALEA_TOWN
--- a/maps/BillsFamilysHouse.asm
+++ b/maps/BillsFamilysHouse.asm
@@ -98,13 +98,13 @@
 	sjump .Refused
 
 BillsHouseBookshelf1:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 BillsHouseBookshelf2:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 BillsHouseRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 BillTakeThisEeveeText:
 	text "BILL: Hi, <PLAYER>!"
--- a/maps/BlackthornCity.asm
+++ b/maps/BlackthornCity.asm
@@ -137,10 +137,10 @@
 	jumptext BlackthornCityTrainerTipsText
 
 BlackthornCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 BlackthornCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 Text_ClairIsOut:
 	text "I am sorry."
--- a/maps/BlackthornDragonSpeechHouse.asm
+++ b/maps/BlackthornDragonSpeechHouse.asm
@@ -20,11 +20,11 @@
 
 ; unused
 BlackthornDragonSpeechHousePictureBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 ; unused
 BlackthornDragonSpeechHouseMagazineBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 BlackthornDragonSpeechHouseGrannyText:
 	text "A clan of trainers"
--- a/maps/BlackthornEmysHouse.asm
+++ b/maps/BlackthornEmysHouse.asm
@@ -15,7 +15,7 @@
 	end
 
 EmysHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 BlackthornEmysHouse_MapEvents:
 	db 0, 0 ; filler
--- a/maps/BlackthornGym1F.asm
+++ b/maps/BlackthornGym1F.asm
@@ -142,10 +142,10 @@
 BlackthornGymStatue:
 	checkflag ENGINE_RISINGBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, CLAIR, CLAIR1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 ClairIntroText:
 	text "I am CLAIR."
--- a/maps/BlackthornGym2F.asm
+++ b/maps/BlackthornGym2F.asm
@@ -54,7 +54,7 @@
 	end
 
 BlackthornGymBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 TrainerCooltrainermCody:
 	trainer COOLTRAINERM, CODY, EVENT_BEAT_COOLTRAINERM_CODY, CooltrainermCodySeenText, CooltrainermCodyBeatenText, 0, .Script
--- a/maps/BlackthornPokecenter1F.asm
+++ b/maps/BlackthornPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 BlackthornPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 BlackthornPokecenter1FGentlemanScript:
 	jumptextfaceplayer BlackthornPokecenter1FGentlemanText
@@ -19,7 +19,7 @@
 	jumptextfaceplayer BlackthornPokecenter1FTwinText
 
 BlackthornPokecenter1FCooltrainerMScript:
-	jumpstd happinesschecknpc
+	jumpstd HappinessCheckScript
 
 BlackthornPokecenter1FGentlemanText:
 	text "Deep inside far-"
--- a/maps/BurnedTower1F.asm
+++ b/maps/BurnedTower1F.asm
@@ -126,7 +126,7 @@
 	jumptextfaceplayer BurnedTower1FMortyText
 
 BurnedTower1FRock:
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 BurnedTower1FHiddenEther:
 	hiddenitem ETHER, EVENT_BURNED_TOWER_1F_HIDDEN_ETHER
--- a/maps/BurnedTowerB1F.asm
+++ b/maps/BurnedTowerB1F.asm
@@ -120,7 +120,7 @@
 	itemball TM_ENDURE
 
 BurnedTowerB1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 BurnedTowerRaikouMovement:
 	set_sliding
--- a/maps/CeladonCafe.asm
+++ b/maps/CeladonCafe.asm
@@ -114,7 +114,7 @@
 	end
 
 .TrashEmpty:
-	jumpstd trashcan
+	jumpstd TrashCanScript
 
 ChefText_Eatathon:
 	text "Hi!"
--- a/maps/CeladonCity.asm
+++ b/maps/CeladonCity.asm
@@ -70,7 +70,7 @@
 	jumptext CeladonCityTrainerTipsText
 
 CeladonCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 CeladonCityHiddenPpUp:
 	hiddenitem PP_UP, EVENT_CELADON_CITY_HIDDEN_PP_UP
--- a/maps/CeladonDeptStore1F.asm
+++ b/maps/CeladonDeptStore1F.asm
@@ -21,7 +21,7 @@
 	jumptext CeladonDeptStore1FDirectoryText
 
 CeladonDeptStore1FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 CeladonDeptStore1FReceptionistText:
 	text "Hello! Welcome to"
--- a/maps/CeladonDeptStore2F.asm
+++ b/maps/CeladonDeptStore2F.asm
@@ -33,7 +33,7 @@
 	jumptext CeladonDeptStore2FDirectoryText
 
 CeladonDeptStore2FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 CeladonDeptStore2FPokefanMText:
 	text "I just recently"
--- a/maps/CeladonDeptStore3F.asm
+++ b/maps/CeladonDeptStore3F.asm
@@ -42,7 +42,7 @@
 	jumptextfaceplayer CeladonDeptStore3FSuperNerdText
 
 CeladonDeptStore3FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 CeladonDeptStore3FDirectory:
 	jumptext CeladonDeptStore3FDirectoryText
--- a/maps/CeladonDeptStore4F.asm
+++ b/maps/CeladonDeptStore4F.asm
@@ -25,7 +25,7 @@
 	jumptext CeladonDeptStore4FDirectoryText
 
 CeladonDeptStore4FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 CeladonDeptStore4FSuperNerdText:
 	text "I'm here to buy"
--- a/maps/CeladonDeptStore5F.asm
+++ b/maps/CeladonDeptStore5F.asm
@@ -37,7 +37,7 @@
 	jumptext CeladonDeptStore5FDirectoryText
 
 CeladonDeptStore5FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 CeladonDeptStore5FGentlemanText:
 	text "I want to buy some"
--- a/maps/CeladonDeptStore6F.asm
+++ b/maps/CeladonDeptStore6F.asm
@@ -100,7 +100,7 @@
 
 ; unused
 CeladonDeptStore6FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 CeladonVendingText:
 	text "A vending machine!"
--- a/maps/CeladonGameCorner.asm
+++ b/maps/CeladonGameCorner.asm
@@ -15,7 +15,7 @@
 	db 0 ; callbacks
 
 CeladonGameCornerClerkScript:
-	jumpstd gamecornercoinvendor
+	jumpstd GameCornerCoinVendorScript
 
 CeladonGameCornerReceptionistScript:
 	jumptextfaceplayer CeladonGameCornerReceptionistText
@@ -70,7 +70,7 @@
 	end
 
 .GiveCoins:
-	jumpstd receiveitem
+	jumpstd ReceiveItemScript
 	end
 
 .coinname
--- a/maps/CeladonGym.asm
+++ b/maps/CeladonGym.asm
@@ -105,10 +105,10 @@
 CeladonGymStatue:
 	checkflag ENGINE_RAINBOWBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, ERIKA, ERIKA1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 ErikaBeforeBattleText:
 	text "ERIKA: Hello…"
--- a/maps/CeladonMansion1F.asm
+++ b/maps/CeladonMansion1F.asm
@@ -40,7 +40,7 @@
 	jumptext CeladonMansionManagersSuiteSignText
 
 CeladonMansion1FBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 CeladonMansionManagerText:
 	text "My dear #MON"
--- a/maps/CeladonMansion2F.asm
+++ b/maps/CeladonMansion2F.asm
@@ -10,7 +10,7 @@
 	jumptext CeladonMansion2FMeetingRoomSignText
 
 CeladonMansion2FBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 CeladonMansion2FComputerText:
 	text "<PLAYER> turned on"
--- a/maps/CeladonPokecenter1F.asm
+++ b/maps/CeladonPokecenter1F.asm
@@ -11,10 +11,10 @@
 	db 0 ; callbacks
 
 CeladonPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 CeladonPokecenter1FGentlemanScript:
-	jumpstd happinesschecknpc
+	jumpstd HappinessCheckScript
 
 CeladonPokecenter1FCooltrainerFScript:
 	jumptextfaceplayer CeladonPokecenter1FCooltrainerFText
--- a/maps/CeruleanCity.asm
+++ b/maps/CeruleanCity.asm
@@ -139,10 +139,10 @@
 	jumptext CeruleanLockedDoorText
 
 CeruleanCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 CeruleanCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 CeruleanCityHiddenBerserkGene:
 	hiddenitem BERSERK_GENE, EVENT_FOUND_BERSERK_GENE_IN_CERULEAN_CITY
--- a/maps/CeruleanGym.asm
+++ b/maps/CeruleanGym.asm
@@ -156,10 +156,10 @@
 CeruleanGymStatue:
 	checkflag ENGINE_CASCADEBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, MISTY, MISTY1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 CeruleanGymGruntRunsDownMovement:
 	big_step DOWN
--- a/maps/CeruleanPokecenter1F.asm
+++ b/maps/CeruleanPokecenter1F.asm
@@ -9,7 +9,7 @@
 	db 0 ; callbacks
 
 CeruleanPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 CeruleanPokecenter1FSuperNerdScript:
 	special Mobile_DummyReturnFalse
--- a/maps/CharcoalKiln.asm
+++ b/maps/CharcoalKiln.asm
@@ -70,10 +70,10 @@
 	end
 
 CharcoalKilnBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 CharcoalKilnRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 CharcoalKilnBossText1:
 	text "All the SLOWPOKE"
--- a/maps/CherrygroveCity.asm
+++ b/maps/CherrygroveCity.asm
@@ -86,7 +86,7 @@
 	end
 
 .JumpstdReceiveItem:
-	jumpstd receiveitem
+	jumpstd ReceiveItemScript
 	end
 
 .mapcardname
@@ -230,10 +230,10 @@
 	jumptext GuideGentsHouseSignText
 
 CherrygroveCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 CherrygroveCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 GuideGentMovement1:
 	step LEFT
--- a/maps/CherrygroveEvolutionSpeechHouse.asm
+++ b/maps/CherrygroveEvolutionSpeechHouse.asm
@@ -22,7 +22,7 @@
 	end
 
 CherrygroveEvolutionSpeechHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 CherrygroveEvolutionSpeechHouseYoungsterText:
 	text "#MON gain expe-"
--- a/maps/CherrygroveGymSpeechHouse.asm
+++ b/maps/CherrygroveGymSpeechHouse.asm
@@ -14,7 +14,7 @@
 	jumptextfaceplayer CherrygroveGymSpeechHouseBugCatcherText
 
 CherrygroveGymSpeechHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 CherrygroveGymSpeechHousePokefanMText:
 	text "You're trying to"
--- a/maps/CherrygrovePokecenter1F.asm
+++ b/maps/CherrygrovePokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 CherrygrovePokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 CherrygrovePokecenter1FFisherScript:
 	jumptextfaceplayer CherrygrovePokecenter1FFisherText
--- a/maps/CianwoodCity.asm
+++ b/maps/CianwoodCity.asm
@@ -138,10 +138,10 @@
 	jumptext CianwoodPokeSeerSignText
 
 CianwoodPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 CianwoodCityRock:
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 CianwoodCityHiddenRevive:
 	hiddenitem REVIVE, EVENT_CIANWOOD_CITY_HIDDEN_REVIVE
--- a/maps/CianwoodGym.asm
+++ b/maps/CianwoodGym.asm
@@ -79,10 +79,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 TrainerBlackbeltYoshi:
 	trainer BLACKBELT_T, YOSHI, EVENT_BEAT_BLACKBELT_YOSHI, BlackbeltYoshiSeenText, BlackbeltYoshiBeatenText, 0, .Script
@@ -129,15 +129,15 @@
 	end
 
 CianwoodGymBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 CianwoodGymStatue:
 	checkflag ENGINE_STORMBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, CHUCK, CHUCK1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 CianwoodGymMovement_ChuckChucksBoulder:
 	set_sliding
--- a/maps/CianwoodLugiaSpeechHouse.asm
+++ b/maps/CianwoodLugiaSpeechHouse.asm
@@ -18,7 +18,7 @@
 	jumptextfaceplayer CianwoodLugiaSpeechHouseTwinText
 
 CianwoodLugiaSpeechHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 CianwoodLugiaSpeechHouseTeacherText:
 	text "You came from"
--- a/maps/CianwoodPharmacy.asm
+++ b/maps/CianwoodPharmacy.asm
@@ -36,7 +36,7 @@
 	end
 
 CianwoodPharmacyBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 PharmacistGiveSecretpotionText:
 	text "Your #MON ap-"
--- a/maps/CianwoodPokecenter1F.asm
+++ b/maps/CianwoodPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 CianwoodPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 CianwoodPokecenter1FLassScript:
 	jumptextfaceplayer CianwoodPokecenter1FLassText
--- a/maps/CinnabarIsland.asm
+++ b/maps/CinnabarIsland.asm
@@ -30,7 +30,7 @@
 	jumptext CinnabarIslandSignText
 
 CinnabarIslandPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 CinnabarIslandHiddenRareCandy:
 	hiddenitem RARE_CANDY, EVENT_CINNABAR_ISLAND_HIDDEN_RARE_CANDY
--- a/maps/CinnabarPokecenter1F.asm
+++ b/maps/CinnabarPokecenter1F.asm
@@ -9,7 +9,7 @@
 	db 0 ; callbacks
 
 CinnabarPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 CinnabarPokecenter1FCooltrainerFScript:
 	jumptextfaceplayer CinnabarPokecenter1FCooltrainerFText
--- a/maps/CopycatsHouse2F.asm
+++ b/maps/CopycatsHouse2F.asm
@@ -184,7 +184,7 @@
 	jumptext CopycatsHouse2FDollText
 
 CopycatsHouse2FBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 CopycatSpinAroundMovementData:
 	turn_head DOWN
--- a/maps/DarkCaveVioletEntrance.asm
+++ b/maps/DarkCaveVioletEntrance.asm
@@ -26,7 +26,7 @@
 	itemball DIRE_HIT
 
 DarkCaveVioletEntranceRock:
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 DarkCaveVioletEntranceHiddenElixer:
 	hiddenitem ELIXER, EVENT_DARK_CAVE_VIOLET_ENTRANCE_HIDDEN_ELIXER
--- a/maps/DayCare.asm
+++ b/maps/DayCare.asm
@@ -71,7 +71,7 @@
 	end
 
 DayCareBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 Text_GrampsLookingForYou:
 	text "Gramps was looking"
--- a/maps/EarlsPokemonAcademy.asm
+++ b/maps/EarlsPokemonAcademy.asm
@@ -143,7 +143,7 @@
 	jumptext AcademyStickerMachineText
 
 AcademyBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 AcademyEarlSpinMovement:
 	turn_head DOWN
--- a/maps/EcruteakCity.asm
+++ b/maps/EcruteakCity.asm
@@ -80,10 +80,10 @@
 	jumptext BurnedTowerSignText
 
 EcruteakCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 EcruteakCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 EcruteakCityHiddenHyperPotion:
 	hiddenitem HYPER_POTION, EVENT_ECRUTEAK_CITY_HIDDEN_HYPER_POTION
--- a/maps/EcruteakGym.asm
+++ b/maps/EcruteakGym.asm
@@ -74,10 +74,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 EcruteakGymClosed:
 	applymovement PLAYER, EcruteakGymPlayerStepUpMovement
@@ -158,10 +158,10 @@
 EcruteakGymStatue:
 	checkflag ENGINE_FOGBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, MORTY, MORTY1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 EcruteakGymPlayerStepUpMovement:
 	step UP
--- a/maps/EcruteakItemfinderHouse.asm
+++ b/maps/EcruteakItemfinderHouse.asm
@@ -53,7 +53,7 @@
 	end
 
 ItemFinderHouseRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 EcruteakItemfinderAdventureText:
 	text "Ah. You're on an"
--- a/maps/EcruteakLugiaSpeechHouse.asm
+++ b/maps/EcruteakLugiaSpeechHouse.asm
@@ -14,7 +14,7 @@
 	jumptextfaceplayer EcruteakLugiaSpeechHouseYoungsterText
 
 LugiaSpeechHouseRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 EcruteakLugiaSpeechHouseGrampsText:
 	text "This happened when"
--- a/maps/EcruteakPokecenter1F.asm
+++ b/maps/EcruteakPokecenter1F.asm
@@ -56,7 +56,7 @@
 	end
 
 EcruteakPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 EcruteakPokecenter1FPokefanMScript:
 	special Mobile_DummyReturnFalse
--- a/maps/ElmsHouse.asm
+++ b/maps/ElmsHouse.asm
@@ -17,7 +17,7 @@
 	jumptext ElmsHousePCText
 
 ElmsHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 ElmsWifeText:
 	text "Hi, <PLAY_G>! My"
--- a/maps/ElmsLab.asm
+++ b/maps/ElmsLab.asm
@@ -509,7 +509,7 @@
 	end
 
 AideScript_ReceiveTheBalls:
-	jumpstd receiveitem
+	jumpstd ReceiveItemScript
 	end
 
 ElmsAideScript:
@@ -603,10 +603,10 @@
 
 ElmsLabTrashcan2:
 ; unused
-	jumpstd trashcan
+	jumpstd TrashCanScript
 
 ElmsLabBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 ElmsLab_WalkUpToElmMovement:
 	step UP
--- a/maps/FastShipB1F.asm
+++ b/maps/FastShipB1F.asm
@@ -202,7 +202,7 @@
 	end
 
 FastShipB1FTrashcan:
-	jumpstd trashcan
+	jumpstd TrashCanScript
 
 FastShipB1FSailorBlocksRightMovement:
 	fix_facing
--- a/maps/FastShipCabins_NNW_NNE_NE.asm
+++ b/maps/FastShipCabins_NNW_NNE_NE.asm
@@ -113,7 +113,7 @@
 	end
 
 FastShipCabins_NNW_NNE_NETrashcan:
-	jumpstd trashcan
+	jumpstd TrashCanScript
 
 FastShipLazySailorLeavesMovement1:
 	step LEFT
--- a/maps/FastShipCabins_SE_SSE_CaptainsCabin.asm
+++ b/maps/FastShipCabins_SE_SSE_CaptainsCabin.asm
@@ -216,7 +216,7 @@
 	end
 
 FastShipCaptainsCabinTrashcan:
-	jumpstd trashcan
+	jumpstd TrashCanScript
 
 MovementData_0x76004:
 	big_step RIGHT
--- a/maps/FastShipCabins_SW_SSW_NW.asm
+++ b/maps/FastShipCabins_SW_SSW_NW.asm
@@ -109,7 +109,7 @@
 	end
 
 FastShipCabinsNorthwestCabinTrashcan:
-	jumpstd trashcan
+	jumpstd TrashCanScript
 
 FirebreatherLyleSeenText:
 	text "I'm going to KANTO"
--- a/maps/FuchsiaCity.asm
+++ b/maps/FuchsiaCity.asm
@@ -42,10 +42,10 @@
 	jumptext NoLitteringSignText
 
 FuchsiaCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 FuchsiaCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 FuchsiaCityFruitTree:
 	fruittree FRUITTREE_FUCHSIA_CITY
--- a/maps/FuchsiaGym.asm
+++ b/maps/FuchsiaGym.asm
@@ -212,10 +212,10 @@
 FuchsiaGymStatue:
 	checkflag ENGINE_SOULBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, JANINE, JANINE1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 Movement_NinjaSpin:
 	turn_head DOWN
--- a/maps/FuchsiaPokecenter1F.asm
+++ b/maps/FuchsiaPokecenter1F.asm
@@ -14,7 +14,7 @@
 	end
 
 FuchsiaPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 FuchsiaPokecenter1FCooltrainerMScript:
 	jumptextfaceplayer FuchsiaPokecenter1FCooltrainerMText
--- a/maps/GoldenrodCity.asm
+++ b/maps/GoldenrodCity.asm
@@ -262,7 +262,7 @@
 	jumptext GoldenrodCityUndergroundSignSouthText
 
 GoldenrodCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 GoldenrodCityFlowerShopSign:
 	jumptext GoldenrodCityFlowerShopSignText
--- a/maps/GoldenrodDeptStore1F.asm
+++ b/maps/GoldenrodDeptStore1F.asm
@@ -25,7 +25,7 @@
 	jumptext GoldenrodDeptStore1FDirectoryText
 
 GoldenrodDeptStore1FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 GoldenrodDeptStore1FReceptionistText:
 	text "Welcome to GOLDEN-"
--- a/maps/GoldenrodDeptStore2F.asm
+++ b/maps/GoldenrodDeptStore2F.asm
@@ -37,7 +37,7 @@
 	jumptext GoldenrodDeptStore2FDirectoryText
 
 GoldenrodDeptStore2FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 GoldenrodDeptStore2FUnusedText1:
 ; unused
--- a/maps/GoldenrodDeptStore3F.asm
+++ b/maps/GoldenrodDeptStore3F.asm
@@ -25,7 +25,7 @@
 	jumptext GoldenrodDeptStore3FDirectoryText
 
 GoldenrodDeptStore3FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 GoldenrodDeptStore3FSuperNerdText:
 	text "I, I, I'm really"
--- a/maps/GoldenrodDeptStore4F.asm
+++ b/maps/GoldenrodDeptStore4F.asm
@@ -35,7 +35,7 @@
 	jumptext GoldenrodDeptStore4FDirectoryText
 
 GoldenrodDeptStore4FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 GoldenrodDeptStore4FCooltrainerMText:
 	text "Hey. I love strong"
--- a/maps/GoldenrodDeptStore5F.asm
+++ b/maps/GoldenrodDeptStore5F.asm
@@ -136,7 +136,7 @@
 	jumptext GoldenrodDeptStore5FDirectoryText
 
 GoldenrodDeptStore5FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 GoldenrodDeptStore5FReceptionistOhYourMonDotDotDotText:
 	text "Hello. Oh, your"
--- a/maps/GoldenrodDeptStore6F.asm
+++ b/maps/GoldenrodDeptStore6F.asm
@@ -94,7 +94,7 @@
 	jumptext GoldenrodDeptStore6FDirectoryText
 
 GoldenrodDeptStore6FElevatorButton:
-	jumpstd elevatorbutton
+	jumpstd ElevatorButtonScript
 
 GoldenrodVendingText:
 	text "A vending machine!"
--- a/maps/GoldenrodFlowerShop.asm
+++ b/maps/GoldenrodFlowerShop.asm
@@ -75,15 +75,15 @@
 
 FlowerShopShelf1:
 ; unused
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 FlowerShopShelf2:
 ; unused
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 FlowerShopRadio:
 ; unused
-	jumpstd radio2
+	jumpstd Radio2Script
 
 GoldenrodFlowerShopTeacherMySisterWentToSeeWigglyTreeRoute36Text:
 	text "Have you seen that"
--- a/maps/GoldenrodGameCorner.asm
+++ b/maps/GoldenrodGameCorner.asm
@@ -54,7 +54,7 @@
 	end
 
 GoldenrodGameCornerCoinVendorScript:
-	jumpstd gamecornercoinvendor
+	jumpstd GameCornerCoinVendorScript
 
 GoldenrodGameCornerTMVendorScript:
 	faceplayer
--- a/maps/GoldenrodGym.asm
+++ b/maps/GoldenrodGym.asm
@@ -85,10 +85,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 TrainerLassCarrie:
 	trainer LASS, CARRIE, EVENT_BEAT_LASS_CARRIE, LassCarrieSeenText, LassCarrieBeatenText, 0, .Script
@@ -167,10 +167,10 @@
 GoldenrodGymStatue:
 	checkflag ENGINE_PLAINBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, WHITNEY, WHITNEY1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 BridgetWalksUpMovement:
 	step LEFT
--- a/maps/GoldenrodHappinessRater.asm
+++ b/maps/GoldenrodHappinessRater.asm
@@ -64,10 +64,10 @@
 	jumptextfaceplayer GoldenrodHappinessRaterTwinText
 
 HappinessRatersHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 HappinessRatersHouseRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 GoldenrodHappinessRaterTeacherText:
 	text "If you treat your"
--- a/maps/GoldenrodNameRater.asm
+++ b/maps/GoldenrodNameRater.asm
@@ -15,10 +15,10 @@
 	end
 
 GoldenrodNameRaterBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 GoldenrodNameRaterRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 INCLUDE "data/text/unused_sweet_honey.asm"
 
--- a/maps/GoldenrodPPSpeechHouse.asm
+++ b/maps/GoldenrodPPSpeechHouse.asm
@@ -14,13 +14,13 @@
 	jumptextfaceplayer GoldenrodPPSpeechHouseLassText
 
 GoldenrodPPSpeechHouseBookshelf2:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 GoldenrodPPSpeechHouseBookshelf1:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 GoldenrodPPSpeechHouseRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 GoldenrodPPSpeechHouseFisherText:
 	text "Once while I was"
--- a/maps/GoldenrodPokecenter1F.asm
+++ b/maps/GoldenrodPokecenter1F.asm
@@ -11,7 +11,7 @@
 	db 0 ; callbacks
 
 GoldenrodPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 GoldenrodPokecenter1F_GSBallSceneLeft:
 	setval BATTLETOWERACTION_CHECKMOBILEEVENT
--- a/maps/GuideGentsHouse.asm
+++ b/maps/GuideGentsHouse.asm
@@ -10,7 +10,7 @@
 	jumptextfaceplayer GuideGentsHouseGuideGentText
 
 GuideGentsHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 GuideGentsHouseGuideGentText:
 	text "When I was a wee"
--- a/maps/IcePathB1F.asm
+++ b/maps/IcePathB1F.asm
@@ -60,7 +60,7 @@
 	end
 
 IcePathB1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 IcePathB1FIron:
 	itemball IRON
--- a/maps/IcePathB3F.asm
+++ b/maps/IcePathB3F.asm
@@ -11,7 +11,7 @@
 	itemball NEVERMELTICE
 
 IcePathB3FRock:
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 IcePathB3F_MapEvents:
 	db 0, 0 ; filler
--- a/maps/IlexForest.asm
+++ b/maps/IlexForest.asm
@@ -422,7 +422,7 @@
 
 IlexForestBoulder:
 ; unused
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 IlexForestSignpost:
 	jumptext IlexForestSignpostText
--- a/maps/IndigoPlateauPokecenter1F.asm
+++ b/maps/IndigoPlateauPokecenter1F.asm
@@ -135,7 +135,7 @@
 	end
 
 IndigoPlateauPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 IndigoPlateauPokecenter1FClerkScript:
 	opentext
--- a/maps/KurtsHouse.asm
+++ b/maps/KurtsHouse.asm
@@ -426,10 +426,10 @@
 	jumptext KurtsHouseCelebiStatueText
 
 KurtsHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 KurtsHouseRadio:
-	jumpstd radio2
+	jumpstd Radio2Script
 
 KurtsHouseKurtExitHouseMovement:
 	big_step DOWN
--- a/maps/LakeOfRageHiddenPowerHouse.asm
+++ b/maps/LakeOfRageHiddenPowerHouse.asm
@@ -28,7 +28,7 @@
 	end
 
 HiddenPowerHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 HiddenPowerGuyText1:
 	text "…You have strayed"
--- a/maps/LakeOfRageMagikarpHouse.asm
+++ b/maps/LakeOfRageMagikarpHouse.asm
@@ -88,7 +88,7 @@
 	jumptext LakeOfRageMagikarpHouseUnusedRecordText
 
 MagikarpHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 MagikarpLengthRaterText_LakeOfRageHistory:
 	text "LAKE OF RAGE is"
--- a/maps/LavRadioTower1F.asm
+++ b/maps/LavRadioTower1F.asm
@@ -44,7 +44,7 @@
 	end
 
 .receiveitem:
-	jumpstd receiveitem
+	jumpstd ReceiveItemScript
 	end
 
 .expncardname
--- a/maps/LavenderNameRater.asm
+++ b/maps/LavenderNameRater.asm
@@ -20,7 +20,7 @@
 
 LavenderNameRaterUnusedBookshelf:
 ; unused
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 LavenderNameRater_MapEvents:
 	db 0, 0 ; filler
--- a/maps/LavenderPokecenter1F.asm
+++ b/maps/LavenderPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 LavenderPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 LavenderPokecenter1FGentlemanScript:
 	jumptextfaceplayer LavenderPokecenter1FGentlemanText
--- a/maps/LavenderSpeechHouse.asm
+++ b/maps/LavenderSpeechHouse.asm
@@ -10,7 +10,7 @@
 	jumptextfaceplayer LavenderSpeechHousePokefanFText
 
 LavenderSpeechHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 LavenderSpeechHousePokefanFText:
 	text "LAVENDER is a"
--- a/maps/LavenderTown.asm
+++ b/maps/LavenderTown.asm
@@ -39,10 +39,10 @@
 	jumptext SoulHouseSignText
 
 LavenderPokecenterSignText:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 LavenderMartSignText:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 LavenderTownPokefanMText:
 	text "That's quite some"
--- a/maps/MahoganyGym.asm
+++ b/maps/MahoganyGym.asm
@@ -63,10 +63,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 TrainerSkierRoxanne:
 	trainer SKIER, ROXANNE, EVENT_BEAT_SKIER_ROXANNE, SkierRoxanneSeenText, SkierRoxanneBeatenText, 0, .Script
@@ -142,10 +142,10 @@
 MahoganyGymStatue:
 	checkflag ENGINE_GLACIERBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, PRYCE, PRYCE1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 PryceText_Intro:
 	text "#MON have many"
--- a/maps/MahoganyPokecenter1F.asm
+++ b/maps/MahoganyPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 MahoganyPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 MahoganyPokecenter1FPokefanMScript:
 	jumptextfaceplayer MahoganyPokecenter1FPokefanMText
--- a/maps/MahoganyRedGyaradosSpeechHouse.asm
+++ b/maps/MahoganyRedGyaradosSpeechHouse.asm
@@ -28,11 +28,11 @@
 
 MahoganyRedGyaradosSpeechHouseUnusedBookshelf1:
 ; unused
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 MahoganyRedGyaradosSpeechHouseUnusedBookshelf2:
 ; unused
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 MahoganyRedGyaradosSpeechHouseBlackBeltText:
 	text "I heard that a red"
--- a/maps/MahoganyTown.asm
+++ b/maps/MahoganyTown.asm
@@ -119,7 +119,7 @@
 	jumptext MahoganyGymSignText
 
 MahoganyTownPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 MovementData_0x1900a4:
 	step DOWN
--- a/maps/ManiasHouse.asm
+++ b/maps/ManiasHouse.asm
@@ -97,7 +97,7 @@
 
 ManiasHouseUnusedBookshelf:
 ; unused
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 ManiaText_AskLookAfterShuckle:
 	text "I, I'm in shock!"
--- a/maps/MountMoonSquare.asm
+++ b/maps/MountMoonSquare.asm
@@ -79,7 +79,7 @@
 	jumptext DontLitterSignText
 
 MtMoonSquareRock:
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 PlayerWalksUpToDancingClefairies:
 	step UP
--- a/maps/MountMortar1FInside.asm
+++ b/maps/MountMortar1FInside.asm
@@ -38,7 +38,7 @@
 	end
 
 MountMortar1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 MountMortar1FInsideEscapeRope:
 	itemball ESCAPE_ROPE
--- a/maps/MountMortarB1F.asm
+++ b/maps/MountMortarB1F.asm
@@ -52,7 +52,7 @@
 	end
 
 MountMortarB1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 MountMortarB1FHyperPotion:
 	itemball HYPER_POTION
--- a/maps/MoveDeletersHouse.asm
+++ b/maps/MoveDeletersHouse.asm
@@ -15,7 +15,7 @@
 	end
 
 MoveDeletersHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 MoveDeletersHouse_MapEvents:
 	db 0, 0 ; filler
--- a/maps/MrFujisHouse.asm
+++ b/maps/MrFujisHouse.asm
@@ -41,7 +41,7 @@
 	end
 
 MrFujisHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 MrFujisHouseSuperNerdText:
 	text "MR.FUJI does live"
--- a/maps/MrPsychicsHouse.asm
+++ b/maps/MrPsychicsHouse.asm
@@ -24,7 +24,7 @@
 	end
 
 MrPsychicsHouseBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 MrPsychicText1:
 	text "…"
--- a/maps/NationalPark.asm
+++ b/maps/NationalPark.asm
@@ -159,31 +159,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .RematchStd:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerPokefanmWilliam:
@@ -245,35 +245,35 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .Gift:
-	jumpstd giftf
+	jumpstd GiftFScript
 	end
 
 .PackFull:
-	jumpstd packfullf
+	jumpstd PackFullFScript
 	end
 
 TrainerLassKrise:
--- a/maps/OaksLab.asm
+++ b/maps/OaksLab.asm
@@ -63,7 +63,7 @@
 	jumptextfaceplayer OaksAssistant3Text
 
 OaksLabBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 OaksLabPoster1:
 	jumptext OaksLabPoster1Text
--- a/maps/OlivineCity.asm
+++ b/maps/OlivineCity.asm
@@ -108,10 +108,10 @@
 	jumptext OlivineCityBattleTowerSignText
 
 OlivineCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 OlivineCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 MovementData_0x1a88d2:
 	step DOWN
--- a/maps/OlivineGoodRodHouse.asm
+++ b/maps/OlivineGoodRodHouse.asm
@@ -37,7 +37,7 @@
 
 GoodRodHouseBookshelf:
 ; unused
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 OfferGoodRodText:
 	text "OLIVINE is on the"
--- a/maps/OlivineGym.asm
+++ b/maps/OlivineGym.asm
@@ -53,10 +53,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 OlivineGymGuyScript:
 	faceplayer
@@ -87,10 +87,10 @@
 OlivineGymStatue:
 	checkflag ENGINE_MINERALBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, JASMINE, JASMINE1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 Jasmine_SteelTypeIntro:
 	text "…Thank you for"
--- a/maps/OlivineHouseBeta.asm
+++ b/maps/OlivineHouseBeta.asm
@@ -19,10 +19,10 @@
 	end
 
 OlivineHouseBetaBookshelf1:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 OlivineHouseBetaBookshelf2:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 OlivineHouseBetaTeacherText:
 	text "When my #MON"
--- a/maps/OlivineLighthouse2F.asm
+++ b/maps/OlivineLighthouse2F.asm
@@ -115,40 +115,40 @@
 	sjump .NumberAccepted
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 .PackFull:
 	setevent EVENT_HUEY_PROTEIN
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 .RematchGift:
-	jumpstd rematchgiftm
+	jumpstd RematchGiftMScript
 	end
 
 SailorHueySeenText:
--- a/maps/OlivinePokecenter1F.asm
+++ b/maps/OlivinePokecenter1F.asm
@@ -10,10 +10,10 @@
 	db 0 ; callbacks
 
 OlivinePokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 OlivinePokecenter1FFishingGuruScript:
-	jumpstd happinesschecknpc
+	jumpstd HappinessCheckScript
 
 OlivinePokecenter1FFisherScript:
 	jumptextfaceplayer OlivinePokecenter1FFisherText
--- a/maps/OlivinePunishmentSpeechHouse.asm
+++ b/maps/OlivinePunishmentSpeechHouse.asm
@@ -14,10 +14,10 @@
 	jumptextfaceplayer OlivinePunishmentSpeechHouseDaughterText
 
 OlivinePunishmentSpeechHouseBookshelf2:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 OlivinePunishmentSpeechHouseBookshelf1:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 OlivinePunishmentSpeechHouseDadText:
 	text "Along the way to"
--- a/maps/OlivineTimsHouse.asm
+++ b/maps/OlivineTimsHouse.asm
@@ -15,7 +15,7 @@
 	end
 
 TimsHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 OlivineTimsHouse_MapEvents:
 	db 0, 0 ; filler
--- a/maps/PewterCity.asm
+++ b/maps/PewterCity.asm
@@ -55,10 +55,10 @@
 	jumptext PewterCityWelcomeSignText
 
 PewterCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 PewterCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 PewterCityFruitTree1:
 	fruittree FRUITTREE_PEWTER_CITY_1
--- a/maps/PewterGym.asm
+++ b/maps/PewterGym.asm
@@ -68,10 +68,10 @@
 PewterGymStatue:
 	checkflag ENGINE_BOULDERBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, BROCK, BROCK1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 BrockIntroText:
 	text "BROCK: Wow, it's"
--- a/maps/PewterPokecenter1F.asm
+++ b/maps/PewterPokecenter1F.asm
@@ -11,7 +11,7 @@
 	db 0 ; callbacks
 
 PewterPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 PewterPokecenter1FTeacherScript:
 	jumptextfaceplayer PewterPokecenter1FTeacherText
--- a/maps/PewterSnoozeSpeechHouse.asm
+++ b/maps/PewterSnoozeSpeechHouse.asm
@@ -10,7 +10,7 @@
 	jumptextfaceplayer PewterSnoozeSpeechHouseGrampsText
 
 PewterSnoozeSpeechHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 PewterSnoozeSpeechHouseGrampsText:
 	text "I like snoozing"
--- a/maps/PlayersHouse1F.asm
+++ b/maps/PlayersHouse1F.asm
@@ -107,7 +107,7 @@
 	db "#GEAR@"
 
 PlayersHouse1FReceiveItemStd:
-	jumpstd receiveitem
+	jumpstd ReceiveItemScript
 	end
 
 MomScript:
--- a/maps/PlayersHouse2F.asm
+++ b/maps/PlayersHouse2F.asm
@@ -20,7 +20,7 @@
 	setevent EVENT_TEMPORARY_UNTIL_MAP_RELOAD_8
 	checkevent EVENT_INITIALIZED_EVENTS
 	iftrue .SkipInitialization
-	jumpstd initializeevents
+	jumpstd InitializeEventsScript
 	return
 
 .SkipInitialization:
@@ -71,7 +71,7 @@
 	end
 
 .NormalRadio:
-	jumpstd radio1
+	jumpstd Radio1Script
 
 .AbbreviatedRadio:
 	opentext
@@ -81,7 +81,7 @@
 	end
 
 PlayersHouseBookshelfScript:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 PlayersHousePCScript:
 	opentext
--- a/maps/PlayersNeighborsHouse.asm
+++ b/maps/PlayersNeighborsHouse.asm
@@ -14,7 +14,7 @@
 	jumptextfaceplayer PlayersNeighborText
 
 PlayersNeighborsHouseBookshelfScript:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 PlayersNeighborsHouseRadioScript:
 	checkevent EVENT_GOT_A_POKEMON_FROM_ELM
@@ -36,7 +36,7 @@
 	setevent EVENT_LISTENED_TO_INITIAL_RADIO
 	end
 .NormalRadio:
-	jumpstd radio1
+	jumpstd Radio1Script
 .AbbreviatedRadio:
 	opentext
 	writetext PlayerNeighborRadioText4
--- a/maps/PowerPlant.asm
+++ b/maps/PowerPlant.asm
@@ -195,7 +195,7 @@
 	end
 
 PowerPlantBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 PowerPlantOfficer1ApproachGymGuy2Movement:
 	step RIGHT
--- a/maps/RadioTower1F.asm
+++ b/maps/RadioTower1F.asm
@@ -161,7 +161,7 @@
 	db "RADIO CARD@"
 
 .ReceiveItem:
-	jumpstd receiveitem
+	jumpstd ReceiveItemScript
 	end
 
 .WrongAnswer:
--- a/maps/RadioTower2F.asm
+++ b/maps/RadioTower2F.asm
@@ -335,7 +335,7 @@
 	jumptext RadioTower2FPokemonRadioSignText
 
 RadioTower2FBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 RadioTower2FPlayerWalksToMicrophoneMovement:
 	slow_step DOWN
--- a/maps/RadioTower5F.asm
+++ b/maps/RadioTower5F.asm
@@ -149,7 +149,7 @@
 	jumptext RadioTower5FStudio1SignText
 
 RadioTower5FBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 FakeDirectorMovement:
 	step LEFT
--- a/maps/RedsHouse1F.asm
+++ b/maps/RedsHouse1F.asm
@@ -30,7 +30,7 @@
 	jumptext RedsHouse1FTVText
 
 RedsHouse1FBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 RedsMomText1:
 	text "Hi!"
--- a/maps/Route10North.asm
+++ b/maps/Route10North.asm
@@ -7,7 +7,7 @@
 	jumptext PowerPlantSignText
 
 Route10PokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 PowerPlantSignText:
 	text "KANTO POWER PLANT"
--- a/maps/Route10Pokecenter1F.asm
+++ b/maps/Route10Pokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 Route10Pokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 Route10Pokecenter1FGentlemanScript:
 	jumptextfaceplayer Route10Pokecenter1FGentlemanText
--- a/maps/Route12SuperRodHouse.asm
+++ b/maps/Route12SuperRodHouse.asm
@@ -34,7 +34,7 @@
 
 SuperRodHouseBookshelf:
 ; unused
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 OfferSuperRodText:
 	text "I'm the FISHING"
--- a/maps/Route16FuchsiaSpeechHouse.asm
+++ b/maps/Route16FuchsiaSpeechHouse.asm
@@ -10,7 +10,7 @@
 	jumptextfaceplayer Route16FuchsiaSpeechHouseSuperNerdText
 
 Route16FuchsiaSpeechHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 Route16FuchsiaSpeechHouseSuperNerdText:
 	text "If you cruise down"
--- a/maps/Route26.asm
+++ b/maps/Route26.asm
@@ -90,31 +90,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerCooltrainerfJoyce:
@@ -194,31 +194,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .Rematch:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 TrainerPsychicRichard:
--- a/maps/Route26HealHouse.asm
+++ b/maps/Route26HealHouse.asm
@@ -27,7 +27,7 @@
 	end
 
 Route26HealHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 Route26HealHouseRestAWhileText:
 	text "Your #MON look"
--- a/maps/Route27.asm
+++ b/maps/Route27.asm
@@ -135,39 +135,39 @@
 	sjump .PackFull
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 .Gift:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 .PackFull:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 TrainerCooltrainermBlake:
@@ -258,31 +258,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .Rematch:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 TrainerCooltrainerfMegan:
--- a/maps/Route27SandstormHouse.asm
+++ b/maps/Route27SandstormHouse.asm
@@ -37,7 +37,7 @@
 	end
 
 SandstormHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 SandstormHouseWomanText1:
 	text "Where are you off"
--- a/maps/Route28SteelWingHouse.asm
+++ b/maps/Route28SteelWingHouse.asm
@@ -39,7 +39,7 @@
 	end
 
 CelebrityHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 CelebrityText1:
 	text "Oh, dear."
--- a/maps/Route2NuggetHouse.asm
+++ b/maps/Route2NuggetHouse.asm
@@ -25,7 +25,7 @@
 
 Route2NuggetHouseBookshelf:
 ; unused
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 Route2NuggetHouseFisherText:
 	text "Hi! Wow, I'm glad"
--- a/maps/Route30.asm
+++ b/maps/Route30.asm
@@ -147,40 +147,40 @@
 	sjump .NumberAccepted
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .RematchStd:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 .PackFull:
 	setevent EVENT_JOEY_HP_UP
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 .RematchGift:
-	jumpstd rematchgiftm
+	jumpstd RematchGiftMScript
 	end
 
 TrainerYoungsterMikey:
--- a/maps/Route30BerryHouse.asm
+++ b/maps/Route30BerryHouse.asm
@@ -24,7 +24,7 @@
 	end
 
 Route30BerryHouseBookshelf:
-	jumpstd magazinebookshelf
+	jumpstd MagazineBookshelfScript
 
 Route30BerrySpeechHouseMonEatBerriesText:
 	text "You know, #MON"
--- a/maps/Route31.asm
+++ b/maps/Route31.asm
@@ -145,39 +145,39 @@
 	sjump .PackFullSTD
 
 .AskPhoneNumberSTD:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskAgainSTD:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisterNumberSTD:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .AcceptedNumberSTD:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .DeclinedNumberSTD:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFullSTD:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .RematchSTD:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 .ItemSTD:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 .PackFullSTD:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 Route31MailRecipientScript:
--- a/maps/Route32.asm
+++ b/maps/Route32.asm
@@ -261,31 +261,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .RematchStd:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerFisherHenry:
@@ -389,31 +389,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .RematchStd:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 TrainerYoungsterAlbert:
@@ -501,7 +501,7 @@
 	jumptext Route32UnionCaveSignText
 
 Route32PokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 Route32HiddenGreatBall:
 	hiddenitem GREAT_BALL, EVENT_ROUTE_32_HIDDEN_GREAT_BALL
--- a/maps/Route32Pokecenter1F.asm
+++ b/maps/Route32Pokecenter1F.asm
@@ -9,7 +9,7 @@
 	db 0 ; callbacks
 
 Route32Pokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 Route32Pokecenter1FFishingGuruScript:
 	faceplayer
--- a/maps/Route33.asm
+++ b/maps/Route33.asm
@@ -109,31 +109,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .RematchStd:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 Route33Sign:
--- a/maps/Route34.asm
+++ b/maps/Route34.asm
@@ -183,31 +183,31 @@
 	end
 
 .AskNumber:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .RematchStd:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerPicnickerGina1:
@@ -313,39 +313,39 @@
 	sjump .PackFull
 
 .AskNumber1:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .RematchStd:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 .Gift:
-	jumpstd giftf
+	jumpstd GiftFScript
 	end
 
 .PackFull:
-	jumpstd packfullf
+	jumpstd PackFullFScript
 	end
 
 OfficerKeithScript:
--- a/maps/Route35.asm
+++ b/maps/Route35.asm
@@ -55,31 +55,31 @@
 	sjump Route35NumberAcceptedM
 
 Route35AskNumber1M:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 Route35AskNumber2M:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 Route35RegisteredNumberM:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 Route35NumberAcceptedM:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 Route35NumberDeclinedM:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 Route35PhoneFullM:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 Route35RematchM:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerCamperIvan:
--- a/maps/Route35NationalParkGate.asm
+++ b/maps/Route35NationalParkGate.asm
@@ -64,7 +64,7 @@
 	writetext Route35NationalParkGateOfficer1WaitAtNorthGateText
 	waitbutton
 	closetext
-	jumpstd bugcontestresultswarp
+	jumpstd BugContestResultsWarpScript
 
 .GoBackToContest:
 	writetext Route35NationalParkGateOfficer1OkGoFinishText
@@ -204,7 +204,7 @@
 	jumptext BugCatchingContestExplanationText
 
 Route35NationalParkGate_GetDayOfWeek:
-	jumpstd daytotext
+	jumpstd DayToTextScript
 	end
 
 Route35NationalParkGatePlayerApproachOfficer1Movement:
--- a/maps/Route36.asm
+++ b/maps/Route36.asm
@@ -267,39 +267,39 @@
 	sjump .PackFull
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 .Gift:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 .PackFull:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 TrainerPsychicMark:
--- a/maps/Route36NationalParkGate.asm
+++ b/maps/Route36NationalParkGate.asm
@@ -81,7 +81,7 @@
 	applymovement PLAYER, Route36NationalParkGatePlayerWaitWithContestantsMovement
 	pause 15
 	special FadeInQuickly
-	jumpstd bugcontestresults
+	jumpstd BugContestResultsScript
 
 .GoBackToContest:
 	writetext Route36NationalParkGateOfficer1OkGoFinishText
@@ -300,7 +300,7 @@
 	end
 
 Route36ParkGate_DayToText:
-	jumpstd daytotext
+	jumpstd DayToTextScript
 	end
 
 BugCatchingContestant1BScript:
--- a/maps/Route38.asm
+++ b/maps/Route38.asm
@@ -137,39 +137,39 @@
 	sjump .PackFull
 
 .AskNumber1F:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2F:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredPhoneNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .DeclinedPhoneNumber:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .Rematch:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 .Gift:
-	jumpstd giftf
+	jumpstd GiftFScript
 	end
 
 .PackFull:
-	jumpstd packfullf
+	jumpstd PackFullFScript
 	end
 
 TrainerSchoolboyChad1:
@@ -262,31 +262,31 @@
 	end
 
 .AskPhoneNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskPhoneNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredChad:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .HaveChadsNumber:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .SaidNo:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerBeautyValerie:
--- a/maps/Route39.asm
+++ b/maps/Route39.asm
@@ -71,35 +71,35 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Gift:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 .PackFull:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 TrainerPokefanfRuth:
--- a/maps/Route39Farmhouse.asm
+++ b/maps/Route39Farmhouse.asm
@@ -91,7 +91,7 @@
 	end
 
 FarmhouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 FarmerMText_SickCow:
 	text "My MILTANK ain't"
--- a/maps/Route40.asm
+++ b/maps/Route40.asm
@@ -130,7 +130,7 @@
 	jumptext Route40SignText
 
 Route40Rock:
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 Route40HiddenHyperPotion:
 	hiddenitem HYPER_POTION, EVENT_ROUTE_40_HIDDEN_HYPER_POTION
--- a/maps/Route41.asm
+++ b/maps/Route41.asm
@@ -127,7 +127,7 @@
 
 Route41Rock:
 ; unused
-	jumpstd smashrock
+	jumpstd SmashRockScript
 
 Route41HiddenMaxEther:
 	hiddenitem MAX_ETHER, EVENT_ROUTE_41_HIDDEN_MAX_ETHER
--- a/maps/Route42.asm
+++ b/maps/Route42.asm
@@ -125,39 +125,39 @@
 	sjump .PackFull
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 .Gift:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 .PackFull:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 TrainerPokemaniacShane:
--- a/maps/Route43.asm
+++ b/maps/Route43.asm
@@ -124,31 +124,31 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 .Rematch:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 TrainerPokemaniacRon:
@@ -272,39 +272,39 @@
 	end
 
 .AskNumber1:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 .AskNumber2:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 .RegisteredNumber:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 .NumberAccepted:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 .NumberDeclined:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 .PhoneFull:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 .Rematch:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 .Gift:
-	jumpstd giftf
+	jumpstd GiftFScript
 	end
 
 .PackFull:
-	jumpstd packfullf
+	jumpstd PackFullFScript
 	end
 
 Route43Sign1:
--- a/maps/Route44.asm
+++ b/maps/Route44.asm
@@ -103,48 +103,48 @@
 	sjump Route44NumberAcceptedM
 
 Route44AskNumber1M:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 Route44AskNumber2M:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 Route44RegisteredNumberM:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 Route44NumberAcceptedM:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 Route44NumberDeclinedM:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 Route44PhoneFullM:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 Route44RematchM:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 Route44GiftM:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 Route44PackFullM:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 VancePackFull:
 	setevent EVENT_VANCE_CARBOS
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 Route44RematchGiftM:
-	jumpstd rematchgiftm
+	jumpstd RematchGiftMScript
 	end
 
 TrainerPsychicPhil:
--- a/maps/Route45.asm
+++ b/maps/Route45.asm
@@ -78,48 +78,48 @@
 	sjump Route45PackFullM
 
 Route45AskNumber1M:
-	jumpstd asknumber1m
+	jumpstd AskNumber1MScript
 	end
 
 Route45AskNumber2M:
-	jumpstd asknumber2m
+	jumpstd AskNumber2MScript
 	end
 
 Route45RegisteredNumberM:
-	jumpstd registerednumberm
+	jumpstd RegisteredNumberMScript
 	end
 
 Route45NumberAcceptedM:
-	jumpstd numberacceptedm
+	jumpstd NumberAcceptedMScript
 	end
 
 Route45NumberDeclinedM:
-	jumpstd numberdeclinedm
+	jumpstd NumberDeclinedMScript
 	end
 
 Route45PhoneFullM:
-	jumpstd phonefullm
+	jumpstd PhoneFullMScript
 	end
 
 Route45RematchM:
-	jumpstd rematchm
+	jumpstd RematchMScript
 	end
 
 Route45GiftM:
-	jumpstd giftm
+	jumpstd GiftMScript
 	end
 
 Route45PackFullM:
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 HikerParryHasIron:
 	setevent EVENT_PARRY_IRON
-	jumpstd packfullm
+	jumpstd PackFullMScript
 	end
 
 Route45RematchGiftM:
-	jumpstd rematchgiftm
+	jumpstd RematchGiftMScript
 	end
 
 TrainerHikerErik:
--- a/maps/Route46.asm
+++ b/maps/Route46.asm
@@ -109,40 +109,40 @@
 	sjump Route46NumberAcceptedF
 
 Route46AskNumber1F:
-	jumpstd asknumber1f
+	jumpstd AskNumber1FScript
 	end
 
 Route46AskNumber2F:
-	jumpstd asknumber2f
+	jumpstd AskNumber2FScript
 	end
 
 Route46RegisteredNumberF:
-	jumpstd registerednumberf
+	jumpstd RegisteredNumberFScript
 	end
 
 Route46NumberAcceptedF:
-	jumpstd numberacceptedf
+	jumpstd NumberAcceptedFScript
 	end
 
 Route46NumberDeclinedF:
-	jumpstd numberdeclinedf
+	jumpstd NumberDeclinedFScript
 	end
 
 Route46PhoneFullF:
-	jumpstd phonefullf
+	jumpstd PhoneFullFScript
 	end
 
 Route46RematchF:
-	jumpstd rematchf
+	jumpstd RematchFScript
 	end
 
 ErinNoRoomForCalcium:
 	setevent EVENT_ERIN_CALCIUM
-	jumpstd packfullf
+	jumpstd PackFullFScript
 	end
 
 Route46RematchGiftF:
-	jumpstd rematchgiftf
+	jumpstd RematchGiftFScript
 	end
 
 TrainerHikerBailey:
--- a/maps/Route5CleanseTagHouse.asm
+++ b/maps/Route5CleanseTagHouse.asm
@@ -28,7 +28,7 @@
 	jumptextfaceplayer Route5CleanseTagHouseTeacherText
 
 HouseForSaleBookshelf:
-	jumpstd difficultbookshelf
+	jumpstd DifficultBookshelfScript
 
 Route5CleanseTagHouseGrannyText1:
 	text "Eeyaaaah!"
--- a/maps/SafariZoneWardensHome.asm
+++ b/maps/SafariZoneWardensHome.asm
@@ -29,7 +29,7 @@
 	jumptext SafariZonePhotoText
 
 WardensHomeBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 WardensGranddaughterText1:
 	text "My grandpa is the"
--- a/maps/SaffronCity.asm
+++ b/maps/SaffronCity.asm
@@ -100,10 +100,10 @@
 	jumptext SaffronCityMagnetTrainStationSignText
 
 SaffronCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 SaffronCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 SaffronCityLass1Text:
 	text "A little girl who"
--- a/maps/SaffronGym.asm
+++ b/maps/SaffronGym.asm
@@ -107,10 +107,10 @@
 SaffronGymStatue:
 	checkflag ENGINE_MARSHBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, SABRINA, SABRINA1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 SabrinaIntroText:
 	text "SABRINA: I knew"
--- a/maps/SaffronPokecenter1F.asm
+++ b/maps/SaffronPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 SaffronPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 SaffronPokecenter1FTeacherScript:
 	special Mobile_DummyReturnFalse
--- a/maps/SilverCaveOutside.asm
+++ b/maps/SilverCaveOutside.asm
@@ -9,7 +9,7 @@
 	return
 
 MtSilverPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 MtSilverSign:
 	jumptext MtSilverSignText
--- a/maps/SilverCavePokecenter1F.asm
+++ b/maps/SilverCavePokecenter1F.asm
@@ -8,7 +8,7 @@
 	db 0 ; callbacks
 
 SilverCavePokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 SilverCavePokecenter1FGrannyScript:
 	jumptextfaceplayer SilverCavePokecenter1FGrannyText
--- a/maps/SlowpokeWellB1F.asm
+++ b/maps/SlowpokeWellB1F.asm
@@ -119,7 +119,7 @@
 	end
 
 SlowpokeWellB1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 SlowpokeWellB1FSuperPotion:
 	itemball SUPER_POTION
--- a/maps/TeamRocketBaseB1F.asm
+++ b/maps/TeamRocketBaseB1F.asm
@@ -504,7 +504,7 @@
 	jumptext TeamRocketBaseB1FSecurityCameraText
 
 TeamRocketBaseB1FBookshelf:
-	jumpstd teamrocketoath
+	jumpstd TeamRocketOathScript
 
 TeamRocketBaseB1FSecretSwitch:
 	opentext
--- a/maps/TeamRocketBaseB3F.asm
+++ b/maps/TeamRocketBaseB3F.asm
@@ -200,7 +200,7 @@
 	end
 
 TeamRocketBaseB3FOathScript:
-	jumpstd teamrocketoath
+	jumpstd TeamRocketOathScript
 
 TeamRocketBaseB3FProtein:
 	itemball PROTEIN
--- a/maps/UnionCaveB1F.asm
+++ b/maps/UnionCaveB1F.asm
@@ -63,7 +63,7 @@
 	itemball X_DEFEND
 
 UnionCaveB1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 HikerPhillipSeenText:
 	text "It's been a while"
--- a/maps/VermilionCity.asm
+++ b/maps/VermilionCity.asm
@@ -115,10 +115,10 @@
 	jumptext VermilionCityPortSignText
 
 VermilionCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 VermilionCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 VermilionCityHiddenFullHeal:
 	hiddenitem FULL_HEAL, EVENT_VERMILION_CITY_HIDDEN_FULL_HEAL
--- a/maps/VermilionFishingSpeechHouse.asm
+++ b/maps/VermilionFishingSpeechHouse.asm
@@ -14,7 +14,7 @@
 
 FishingDudesHouseBookshelf:
 ; unused
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 FishingDudeText:
 	text "I am the FISHING"
--- a/maps/VermilionGym.asm
+++ b/maps/VermilionGym.asm
@@ -97,10 +97,10 @@
 VermilionGymStatue:
 	checkflag ENGINE_THUNDERBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, LT_SURGE, LT_SURGE1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 LtSurgeIntroText:
 	text "SURGE: Hey, you"
--- a/maps/VermilionMagnetTrainSpeechHouse.asm
+++ b/maps/VermilionMagnetTrainSpeechHouse.asm
@@ -14,7 +14,7 @@
 	jumptextfaceplayer VermilionMagnetTrainSpeechHouseYoungsterText
 
 VermilionMagnetTrainSpeechHouseBookshelf:
-	jumpstd picturebookshelf
+	jumpstd PictureBookshelfScript
 
 VermilionMagnetTrainSpeechHousePokefanFText:
 	text "Do you know about"
--- a/maps/VermilionPokecenter1F.asm
+++ b/maps/VermilionPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 VermilionPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 VermilionPokecenter1FFishingGuruScript:
 	faceplayer
--- a/maps/VioletCity.asm
+++ b/maps/VioletCity.asm
@@ -81,10 +81,10 @@
 	jumptext EarlsPokemonAcademySignText
 
 VioletCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 VioletCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 VioletCityPPUp:
 	itemball PP_UP
--- a/maps/VioletGym.asm
+++ b/maps/VioletGym.asm
@@ -59,10 +59,10 @@
 	end
 
 .GoldenrodRockets:
-	jumpstd goldenrodrockets
+	jumpstd GoldenrodRocketsScript
 
 .RadioTowerRockets:
-	jumpstd radiotowerrockets
+	jumpstd RadioTowerRocketsScript
 
 TrainerBirdKeeperRod:
 	trainer BIRD_KEEPER, ROD, EVENT_BEAT_BIRD_KEEPER_ROD, BirdKeeperRodSeenText, BirdKeeperRodBeatenText, 0, .Script
@@ -105,10 +105,10 @@
 VioletGymStatue:
 	checkflag ENGINE_ZEPHYRBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 .Beaten:
 	gettrainername STRING_BUFFER_4, FALKNER, FALKNER1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 FalknerIntroText:
 	text "I'm FALKNER, the"
--- a/maps/VioletPokecenter1F.asm
+++ b/maps/VioletPokecenter1F.asm
@@ -11,7 +11,7 @@
 	db 0 ; callbacks
 
 VioletPokecenterNurse:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 VioletPokecenter1F_ElmsAideScript:
 	faceplayer
@@ -56,7 +56,7 @@
 	db "EGG@"
 
 .AideGivesEgg:
-	jumpstd receivetogepiegg
+	jumpstd ReceiveTogepiEggScript
 	end
 
 .PartyFull:
--- a/maps/ViridianCity.asm
+++ b/maps/ViridianCity.asm
@@ -80,10 +80,10 @@
 	jumptext TrainerHouseSignText
 
 ViridianCityPokecenterSign:
-	jumpstd pokecentersign
+	jumpstd PokecenterSignScript
 
 ViridianCityMartSign:
-	jumpstd martsign
+	jumpstd MartSignScript
 
 ViridianCityCoffeeGrampsQuestionText:
 	text "Hey, kid! I just"
--- a/maps/ViridianGym.asm
+++ b/maps/ViridianGym.asm
@@ -55,11 +55,11 @@
 ViridianGymStatue:
 	checkflag ENGINE_EARTHBADGE
 	iftrue .Beaten
-	jumpstd gymstatue1
+	jumpstd GymStatue1Script
 
 .Beaten:
 	gettrainername STRING_BUFFER_4, BLUE, BLUE1
-	jumpstd gymstatue2
+	jumpstd GymStatue2Script
 
 LeaderBlueBeforeText:
 	text "BLUE: Yo! Finally"
--- a/maps/ViridianPokecenter1F.asm
+++ b/maps/ViridianPokecenter1F.asm
@@ -10,7 +10,7 @@
 	db 0 ; callbacks
 
 ViridianPokecenter1FNurseScript:
-	jumpstd pokecenternurse
+	jumpstd PokecenterNurseScript
 
 ViridianPokecenter1FCooltrainerMScript:
 	faceplayer
--- a/maps/WhirlIslandB1F.asm
+++ b/maps/WhirlIslandB1F.asm
@@ -27,7 +27,7 @@
 	itemball ESCAPE_ROPE
 
 WhirlIslandB1FBoulder:
-	jumpstd strengthboulder
+	jumpstd StrengthBoulderScript
 
 WhirlIslandB1FHiddenRareCandy:
 	hiddenitem RARE_CANDY, EVENT_WHIRL_ISLAND_B1F_HIDDEN_RARE_CANDY
--- a/data/events/collision_stdscripts.asm
+++ b/data/events/collision_stdscripts.asm
@@ -1,13 +1,18 @@
 ; stdscripts associated with tile collisions
 
+stdcoll: MACRO
+	db \1
+	dw (\2StdScript - StdScripts) / 3
+ENDM
+
 TileCollisionStdScripts:
-	; collision type,        stdscript
-	dbw COLL_BOOKSHELF,      magazinebookshelf
-	dbw COLL_PC,             pcscript
-	dbw COLL_RADIO,          radio1
-	dbw COLL_TOWN_MAP,       townmap
-	dbw COLL_MART_SHELF,     merchandiseshelf
-	dbw COLL_TV,             tv
-	dbw COLL_WINDOW,         window
-	dbw COLL_INCENSE_BURNER, incenseburner
+	; collision type, std script
+	stdcoll COLL_BOOKSHELF,      MagazineBookshelfScript
+	stdcoll COLL_PC,             PCScript
+	stdcoll COLL_RADIO,          Radio1Script
+	stdcoll COLL_TOWN_MAP,       TownMapScript
+	stdcoll COLL_MART_SHELF,     MerchandiseShelfScript
+	stdcoll COLL_TV,             TVScript
+	stdcoll COLL_WINDOW,         WindowScript
+	stdcoll COLL_INCENSE_BURNER, IncenseBurnerScript
 	db -1 ; end
@@ -1,13 +1,18 @@
-; stdscripts associated with tile collisions
+; std scripts associated with tile collisions
 